/*
    LANChat 4.0 for Windows 95OSR2/98/NT4
   --------------------------------------------------------
    (C) 1998, 1999 Piotr Kowalski (goro@vc.pl)

    LANChat and related utilities are free software; you can
    redistribute it and/or modify it under the terms of the GNU Library
    General Public License as published by the Free Software Foundation;
    either version 2 of the License, or (at your option) any later version.

*/

#if !defined (LANChat_Dialog_INCLUDED)
#define LANChat_Dialog_INCLUDED

#pragma once

/////////////////////////////////////////////////////////////////////////////

#include "PrivateDlg.h"
#include "AwayDlg.h"
#include "TopicDlg.h"
#include "SetupDlg.h"
#include "UsersDlg.h"

// internal boradcast IP address
#define LC_BROADCAST 255

// system-tray icon click
#define WM_TRAY WM_USER+19

#define LAG 100
#define AUTOALIVE 5000

// LANChat messages
#define LC_NEWTOPIC 50
#define LC_TOPIC 53
#define LC_TOPIC_TIME 54
#define LC_CANTPOP 55
#define LC_POPOK 57
#define LC_POPUP 62
#define LC_MOTHER 78
#define LC_NORMAL 100
#define LC_AWAY 101
#define LC_ALIVE 102
#define LC_AWAY_ALIVE 115
#define LC_NEWNICK 116
#define LC_ME 104
#define LC_JOIN 107
#define LC_LEAVE 108
#define LC_REQ_AWAY 110
#define LC_REQ_ALIVE 111
#define LC_START_AWAY 113
#define LC_END_AWAY 114
#define LC_LINUX_MSG 1
#define LC_LINUX_POP 2
#define LC_REQ_STATUS_EX 90
#define LC_STATUS_EX 91
#define LC_SLC_OK 92

// ports
#define INPORT 16128
#define OUTPORT 44145

#define CRYPT_DEFAULT 14
#define CRYPT_SLC 58

// user statuses
#define USER_PRESENT 10
#define USER_AWAY 11
#define USER_GONE 12
#define USER_TIMED 13

#define LANG_UNDEFINED 2

// network packet's structure
typedef struct
{
  char cHead[4];
  unsigned char cType;
  unsigned int cSender;
  unsigned int cDest;
  char cNick[20];
  unsigned char nR;
  unsigned char nG;
  unsigned char nB;
  unsigned char xVal;
  unsigned char cCrypt;
  char Female;
  unsigned long Reserved1;
  unsigned long Reserved2;
  unsigned long Reserved3;
  char Data[4096];
} LC_DATA_HEAD;

// dialog class
class CLANChatDlg : public CDialog
{
public:
  CWinApp *LANChatApp;
  CLANChatDlg(CWnd* pParent = NULL);
  void StdIcon(void);
  void WarnIcon(void);
  void Kolor(int,int,int);
  void Bolden(void);
  void Unbolden(void);
  void OpenSockets(void);
  void SendLCMsg(const int,const int,const char *);
  void DecryptVersion(void);
  void SetNotifyIcon(void);
  void AddText(int,int,int,char *,char,char);
  void Minimize(void);
  void UstawWielkosc(void);
  void CleanNicks(void);
  void SetUser(unsigned int,const int);
  void DeInit(void);
  void Help(void);
  void UpdateList(void);
  void CountLAG(void);
  void Credits(void);
  void InitDialogs(void);
  void SecretMessage(void);
  void SetFonts(void);

  class CMenu *Menu;
  class CTopicDlg *TopicDialog;
  class CAboutDlg *AboutDialog;
  class CUsersDlg *UsersDialog;

  unsigned char MyIP;
  char MsgNick[80];
  char Topic[100];
  char Start[25];
  char Reg;
  unsigned int AutoShow;
  char ActDlg;
  char NetAlive;
  char CryptType[256];

  void WriteConfig(void);
  void ReadConfig(void);

  class CAwayDlg *AwayDialog;
  class CPopUpDlg *PopUpDialog;
  class CSetupDlg *SetupDialog;

  unsigned int MsgIP;
  HINSTANCE hInstance;
  CBitmapButton SndBut;
  CBitmapButton AwBut;
  CBitmapButton MsgBut;

  CBitmapButton AboutBut;
  CBitmapButton TopicBut;
  CBitmapButton SetupBut;

  CBitmapButton ClsBut;
  CBitmapButton MinBut;
  CBitmapButton StatBut;

  int StillAlive;
  char Nick[256][25];
  char Status[256];
  char Said[256];
  char LAGs[256];
  char IPs[256][20];
  unsigned int Language;
  char m_Mute;
  char SnifProt;

  char LANChatVer[30];

  int Minimized;
  int WndStatus;

  void OnCancel(void);

  unsigned char aUsers;

  class CPrivateDlg *PChat[255];

  unsigned int Words[255];
  unsigned long Chars[255];
  unsigned long CHO[255];

  CImageList Mordy;

  void SetVariables(void);

  char HIVER[5];
  char LOVER[5];
  char BUILD[5];

  char m_Away;
  char Dev;
  char Sn;
  char SecondCopy;
  int FirstRun;
  int Truth;
  char omsg;
  char cRecData[ 4196 ];
  char welcome[ 4096 ];
  char message[ 4096 ];
  char FirstTimer;

  char LC_Version[20];
  char LC_OS[15];

  LC_DATA_HEAD OldLC;
  CAsyncSocket SendingSock;
  CAsyncSocket ReceivingSock;
  hostent *pHostEnt;
  CString cIP;
  UINT cPort;

  // GUI variables
  NOTIFYICONDATA NotifyIcon;
  WINDOWPLACEMENT WindowPlcmnt;
  RECT pRect;
  CHARFORMAT FAR CHFormat;
  int nTextLength;
  CString OldText;

  SYSTEMTIME Czas;
  FILE *plik;

  //{{AFX_DATA(CLANChatDlg)
  enum { IDD = IDD_LANCHAT2_DIALOG };
  CListCtrl       m_Users;
  CString m_Wpis;
  //}}AFX_DATA

  //{{AFX_VIRTUAL(CLANChatDlg)
public:
  virtual BOOL DestroyWindow();
  virtual BOOL PreTranslateMessage(MSG* pMsg);
  virtual void WinHelp(DWORD dwData, UINT nCmd = HELP_CONTEXT);
protected:
  virtual void DoDataExchange(CDataExchange* pDX);
  //}}AFX_VIRTUAL

protected:
  HICON m_hIcon;

  //{{AFX_MSG(CLANChatDlg)
  virtual BOOL OnInitDialog();
  afx_msg void OnPaint();
  afx_msg HCURSOR OnQueryDragIcon();
  afx_msg void OnSendMsg();
  afx_msg void OnTimer(UINT nIDEvent);
  afx_msg void OnClose();
  afx_msg int OnUser(WPARAM,LPARAM);
  virtual void OnOK();
  afx_msg void OnMin();
  afx_msg void OnMotherAttack();
  afx_msg void OnCheckAway();
  afx_msg void OnDestroy();
  afx_msg void OnCheckMute();
  afx_msg void OnSetup();
  afx_msg void OnTopic();
  afx_msg void OnAbout();
  afx_msg void OnStatusEx();
  afx_msg void OnClickUsers(NMHDR* pNMHDR, LRESULT* pResult);
  afx_msg void OnDblclkUsers(NMHDR* pNMHDR, LRESULT* pResult);
  //}}AFX_MSG
  DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}

#endif
